#!/usr/bin/perl

use strict;
use Getopt::Std;
use nde;

my %opts;
getopts( 'vheu:t:', \%opts );
if ( $opts{ 'h' } ) { usage(); }

my $command = shift(@ARGV);

my $debug;
if( $opts{ 'v' } ) { $debug = "YES" ; }

if ( ! $ARGV[0] ) { usage(); }

my $timeout = $opts{ 't'};

my $username;
if ( $opts{ 'u' } )
{
        $username = $opts{ 'u' };
}
else
{
        $username = `/usr/bin/whoami`;
        chomp($username); # don't forget this!
}

my $passwd = nde::get_password();

my $enablepasswd;
if( $opts{ 'e' } )
{
        $enablepasswd = nde::get_password("Enable Password: ");
}

foreach my $device (@ARGV)
{
	my $rh = nde::create_session( "", $device, $username, $passwd, $debug, $timeout, $enablepasswd  );
	nde::login();
	my $out;
	if ( $command =~ /\|/ )
	{
		my @commands = split( /\|/, $command );
		$out = nde::run_multi_line_command( \@commands );
	}
	else
	{
		my @commands = split( /&/, $command );
		foreach my $cmd (@commands)
		{
			$out = $out . "\n" .  nde::run_command( $cmd );
		}
	}
	nde::logout();
	print "$device -> $command ->\n$out\n";
}
exit 0;


sub usage
{
	print "usage: $0 [-hve] [-u username] [-t timeout] command device ...\n";
	print "connects to the listed device(s), runs command\n";
	print "then prints out the output.\n";
        print "\n";
	print "command should be passed as a single argument, ie:\n";
        print "$0 \"show ver\" switch\n";
        print "\n";
        print "Multiple commands can be seperated by an amperstand (\&), ie:\n";
        print "$0 \"show ver & show int fa0/1\" switch\n";
        print "\n";
        print "If you don't expect to get a standard prompt back after each command, use a (\|), ie:\n";
        print "$0 \"conf terminal | interface fa0/1 | description bad user | shutdown | end\" switch\n";
        print "(be careful with that one!)\n";
        print "\n";
	print "options:\n";
	print "-h  =  print this message\n";
	print "-v  =  view interactive sessions as they happen\n";
	print "-e  =  prompt for and use an enable password\n";
	print "-u username = use username when logging onto device(s), default is to use output of whoami\n";
	print "-t timeout = wait timeout seconds for responses from device(s), default is to wait 60 seonds\n";
	exit 1;
}

