#!/usr/bin/perl

use strict;
use Getopt::Std;
use nde;

my %opts;
getopts( 'vhsu:', \%opts );
if ( $opts{ 'h' } ) { usage(); }

my $debug;
if( $opts{ 'v' } ) { $debug = "YES" ; }

if ( ! $ARGV[0] ) { usage(); }

my $timeout = $opts{ 't'};

my $username;
if ( $opts{ 'u' } )
{
        $username = $opts{ 'u' };
}
else
{
	$username = `/usr/bin/whoami`;
	chomp($username); # don't forget this!
}



my $passwd = nde::get_password();

my $enablepasswd;
if( $opts{ 'e' } )
{
        $enablepasswd = nde::get_password("Enable Password: ");
}


foreach my $device (@ARGV)
{
	print "working on $device\n";
	my $rh = nde::create_session( "", $device, $username, $passwd, $debug, $timeout, $enablepasswd  );
	nde::login();
	nde::get_type();
	my $error = nde::save_configuration();
	if( $error ) { print "ERROR:\n$error\n"; }
	nde::logout();
	print "done with $device\n";
}
exit 0;


sub usage
{
	print "usage: $0 [-hve] [-u username] [-t timeout] device ...\n";
	print "connects to the listed device(s), and attempts\n";
	print "to save it's running config as the startup config.\n";
	print "(notice, this does not have meaning on all device types (eg catos)).\n";
	print "\n";
	print "options:\n";
	print "-h  =  print this message\n";
	print "-v  =  view interactive sessions as they happen\n";
	print "-e  =  prompt for and use an enable password\n";
	print "-u username = use username when logging onto device(s), default is to use output of whoami\n";
	print "-t timeout = wait timeout seconds for responses from device(s), default is to wait 60 seonds\n";
	exit 1;
}


