#!/usr/bin/perl

use strict;
use Getopt::Std;
use nde;

my $dflt_tftp_server = "192.168.1.1" ; 
my $dflt_timeout = "180" ; 
my %opts;
getopts( 'vhesf:d:t:', \%opts );
if ( $opts{ 'h' } ) { usage(); }

my $src = shift(@ARGV);

my $tftp_server = $opts{ 'f' };
if ( ! $tftp_server ) { $tftp_server = $dflt_tftp_server; }

my $dest = $opts{ 'd' };
if ( ! $dest )
{
	$dest = $src;
	$dest =~ s/^.*\///g;
}
	

my $timeout = $opts{ 't' };
if ( ! $timeout ) { $timeout = $dflt_timeout }

my $debug;
if( $opts{ 'v' } ) { $debug = "YES" ; }

if ( ! $ARGV[0] ) { usage(); }

my $username;
if ( $opts{ 'u' } )
{
        $username = $opts{ 'u' };
}
else
{
	$username = `/usr/bin/whoami`;
	chomp($username); # don't forget this!
}


my $passwd = nde::get_password();
my $enablepasswd;
if( $opts{ 'e' } )
{
        $enablepasswd = nde::get_password("Enable Password: ");
}


foreach my $device (@ARGV)
{
	print "working on $device\n";
	my $rh = nde::create_session( "", $device, $username, $passwd, $debug, $timeout, $enablepasswd  );
	nde::login();
	nde::get_type();
	my $file = $src;
	my $error;
	if ( $$rh{ 'type' } eq "catos" )
	{
		nde::tftp_to_device( $tftp_server, $file, "bootflash:$dest", $timeout );
	}
	else
	{
		nde::tftp_to_device( $tftp_server, $file, $dest, $timeout );
	}
	if( $error ) { print "ERROR:\n$error\n"; }
	if( (! $error) && $opts{ 's' } )
	{
		my $error = nde::save_configuration();
		if( $error ) { print "ERROR:\n$error\n"; }
	}
	nde::logout();
	print "done with $device\n";
}
exit 0;


sub usage
{
	print "usage: $0 [-vhst] [-f tftp_server] [-d destination] [-t timeout] src device ...\n";
	print "connects to the listed device(s), and copies\n";
	print "src FROM tftp_server to flash: on device.\n";
	print "ios devices only\n";
	print "default tftp_server is $dflt_tftp_server\n";
	print "\n";
	print "options:\n";
	print "-e  =  prompt for and use an enable password\n";
	print "-h  =  print this message\n";
	print "-v  =  view interactive sessions as they happen\n";
	print "-t  =  set how long to wait for tftp to finish, default is $dflt_timeout seconds\n";
	print "-u username = use username when logging onto device(s), default is to use output of whoami\n";
	print "-f tftp_server = tftp_server is used instead of the default server\n";
	print "-d dest = specifiy destination filename if different from source file name\n";
	print "           by default dest is src less any paths.\n";
	print "          (ie. configs/default/ios.conf becomes flash:ios.conf)\n";
	print "\n";
	exit 1;
}

